//-----------------------------------------------------------------------------
// Copyright (c) 2012 GarageGames, LLC
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// DefaultTrigger is used by the mission editor.  This is also an example
// of trigger methods and callbacks.

datablock TriggerData(DefaultTrigger)
{
   // The period is value is used to control how often the console
   // onTriggerTick callback is called while there are any objects
   // in the trigger.  The default value is 100 MS.
   tickPeriodMS = 100;
};

datablock TriggerData(ClientTrigger : DefaultTrigger)
{
   clientSide = true;
};

datablock TriggerData(AudioMuffleTrigger)
{
   tickPeriodMS = 100;
   clientSide = true;
};

function AudioMuffleTrigger::onEnterTrigger(%this, %trigger, %obj)
{
   // Only player objects can trigger this
   if ( !%obj.isMemberOfClass( "Player" ) )
      return;
      
   // Make sure we the wind object
   if ( !isObject( ambientWind ) )   
      return;
   else
   {
      ambientWind.pitch = 1.15;
      ambientWind.volume = 0.3;
   }
}

function AudioMuffleTrigger::onLeaveTrigger(%this, %trigger, %obj)
{
   // Only player objects can trigger this
   if ( !%obj.isMemberOfClass( "Player" ) )
      return;
      
   // Make sure we the wind object
   if ( !isObject( ambientWind ) )   
      return;
   else
   {
      ambientWind.pitch = 1;
      ambientWind.volume = 0.5;
   }
}